﻿--[[----------------------------------------------------------------------
      VanasKoS FuBAr Plugin - Part of VanasKoS
Inserts a nice plugin into the FuBar
------------------------------------------------------------------------]]

local VanasKoS = VanasKoS;

VanasKoSFu = VanasKoS:NewModule("VanasKoSFu", "FuBarPlugin-2.0", "AceDB-2.0");
local VanasKoSFu = VanasKoSFu;

local dewdrop = AceLibrary("Dewdrop-2.0");
local tablet = AceLibrary("Tablet-2.0");
local L = AceLibrary("AceLocale-2.2"):new("VanasKoSFu");

VanasKoSFu.hasIcon = "Interface\\Icons\\Ability_Parry";
VanasKoSFu.clickableTooltip = true;
VanasKoSFu.cannotDetachTooltip = true;
VanasKoSFu.independentProfile = true;

L:RegisterTranslations("enUS", function() return {
	["Main Window"] = true,
	["Toggles VanasKoS' Main Window"] = true,
	
	["Warning Window"] = true,
	["Toggles the KoS/Enemy/Friendly Warning Window"] = true,
	["Show Warning Frame Infos as Text and Tooltip"] = true,
	["Last Attackers"] = true,
	["%s ago"] = true,
	
	["Click to toggle the Main Window"] = true,
	
	["Nearby People"] = true,
	
	["Configuration"] = true,
} end);

L:RegisterTranslations("deDE", function() return {
	["Main Window"] = "Hauptfenster",
	["Toggles VanasKoS' Main Window"] = "Zeigt und versteckt VanasKoS' Hauptfenster",
	
	["Warning Window"] = "Warn-Fenster",
	["Toggles the KoS/Enemy/Friendly Warning Window"] = "Schaltet das Warn-Fenster an und aus",
	["Show Warning Frame Infos as Text and Tooltip"] = "Warn-Fenster Infos als Text und Tooltip anzeigen",
	["Last Attackers"] = "Die letzten Angreifer",
	
	["Click to toggle the Main Window"] = "Klicken um Hauptfenster zu zeigen/verstecken",
	
	["Nearby People"] = "Nahe Spieler",
	
	["Configuration"] = "Konfiguration",
} end);

L:RegisterTranslations("frFR", function() return {
	["Main Window"] = "Fenêtre principale",
	["Toggles VanasKoS' Main Window"] = "Afficher/cacher la fenêtre principale de VanasKoS",
	
	["Warning Window"] = "Fenêtre d'avertissement",
	["Toggles the KoS/Enemy/Friendly Warning Window"] = "Afficher/cacher la fenêtre d'avertissement KoS/Ennemi/Amis",
	["Show Warning Frame Infos as Text and Tooltip"] = "Afficher les infos de la fenêtre d'avertissement",
	["Last Attackers"] = "Derniers attaquants",
	["%s ago"] = "Il y'a %s",
	
	["Click to toggle the Main Window"] = "Clique pour afficher/cacher la fenêtre principale",
	
	["Nearby People"] = "Personnes voisines",
	
	["Configuration"] = "Configuration",
} end);

L:RegisterTranslations("koKR", function() return {
	["Main Window"] = "메인창",
	["Toggles VanasKoS' Main Window"] = "VanaKoS 메인창을 열거나 닫습니다.",
	
	["Warning Window"] = "경고창",
	["Toggles the KoS/Enemy/Friendly Warning Window"] = "KoS/적대적/우호적 경고창을 열거나 닫습니다.",
	["Show Warning Frame Infos as Text and Tooltip"] = "텍스트와 툴팁으로 경고창 정보 표시",
	["Last Attackers"] = "마지막 공격자",
	["%s ago"] = "%s 이전",
	
	["Click to toggle the Main Window"] = "메인창을 열거나 닫으려면 클릭하세요.",
	
	["Nearby People"] = "근처에 있는 사람",
	
	["Configuration"] = "환경설정",
} end);

L:RegisterTranslations("ruRU", function() return {
	["Main Window"] = "Главное окно",
	["Toggles VanasKoS' Main Window"] = "Показать главное окно VanasKoS",
	
	["Warning Window"] = "Окно предупреждений",
	["Toggles the KoS/Enemy/Friendly Warning Window"] = "Показывать KoS/Врагов/Друзей в окне предупреждений",
	["Show Warning Frame Infos as Text and Tooltip"] = "Показывать KoS/Врагов/Друзей на панели FuBar",
	["Last Attackers"] = "Последние напавшие",
	["%s ago"] = "%s назад",
	["Click to toggle the Main Window"] = "Щёлкните, чтобы открыть главное окно VanasKoS",
	
	["Nearby People"] = "Ближайшие игроки",
	
	["Configuration"] = "Настройка",
} end);

function VanasKoSFu:UpdateOptions()
	local options = {
		type = 'group',
		args = {
			mainwindow = {
				type = 'toggle',
				name = L["Main Window"],
				desc = L["Toggles VanasKoS' Main Window"],
				order = 1,
				set = "ToggleMainMenu",
				get = function() return VanasKoSFrame:IsVisible(); end,
			},
			warningwindow = {
				type = 'toggle',
				name = L["Warning Window"],
				desc = L["Toggles the KoS/Enemy/Friendly Warning Window"],
				order = 2,
				set = "ToggleWarnFrame",
				get = function() return VanasKoSWarnFrame.db.profile.Enabled; end,
			},
			configuration = {
				type = 'header',
				name = L["Configuration"],
				desc = L["Configuration"],
			},
			showwarnframeinfos = {
				type = 'toggle',
				name = L["Show Warning Frame Infos as Text and Tooltip"],
				desc = L["Show Warning Frame Infos as Text and Tooltip"],
				set = function() VanasKoSFu.db.profile.ShowWarnFrameInfoText = not VanasKoSFu.db.profile.ShowWarnFrameInfoText; VanasKoSFu:EnableOrDisableWarnFrameText(); end,
				get = function() return VanasKoSFu.db.profile.ShowWarnFrameInfoText; end,
			},
		},
	};

	VanasKoSFu.OnMenuRequest = options;
end

function VanasKoSFu:OnInitialize()
	self:RegisterDB("VanasKoSFuDB", "VanasKoSFuDBPC");
	self.text = "VanasKoS";
	self:RegisterDefaults("profile", {
		ShowWarnFrameInfoText = false,
	});
	self:UpdateOptions();
end

function VanasKoSFu:OnEnable()
	self:EnableOrDisableWarnFrameText();
end

function VanasKoSFu:OnDisable()
end

local showWarnFrameInfoText = false;

function VanasKoSFu:EnableOrDisableWarnFrameText()
	showWarnFrameInfoText = self.db.profile.ShowWarnFrameInfoText;
	if(showWarnFrameInfoText) then
		self:RegisterEvent("VanasKoS_Player_Detected", "Player_Detected");
		self:UpdateMyText();
	else
		if(self:IsEventRegistered("VanasKoS_Player_Detected")) then
			self:UnregisterEvent("VanasKoS_Player_Detected");
		end
		self.text = "VanasKoS";
		self:Update();
	end
end

local NOTIFYTIMERINTERVAL = 60;
local nearbyKos = { };
local nearbyEnemys = { };
local nearbyFriendly = { };
local lookupList = { };

function VanasKoSFu:Player_Detected(data)
	local name, faction

	name = data.name
	faction = data.faction
	if(name == nil or showWarnFrameInfoText == false) then
		return;
	end
	
	if(faction == "kos") then
		if(lookupList[name] == nil) then
			lookupList[name] = true;
			tinsert(nearbyKos, { name, faction, data });
		end
		self:CancelScheduledEvent("VanasKoSFuRemovePlayer_" .. name, self.RemovePlayer, self, name);
		self:ScheduleEvent("VanasKoSFuRemovePlayer_" .. name, self.RemovePlayer, NOTIFYTIMERINTERVAL, self, name);
		self:UpdateMyText();

		return nil;
	end
	if(faction == "enemy") then
		if(lookupList[name] == nil) then
			tinsert(nearbyEnemys, { name, faction, data });
		end
	end
	if(faction == "friendly") then
		if(lookupList[name] == nil) then
			tinsert(nearbyFriendly, { name, faction, data });
		end
	end

	if(lookupList[name] == nil) then
		lookupList[name] = true;
		self:CancelScheduledEvent("VanasKoSFuRemovePlayer_" .. name, self.RemovePlayer, self, name);
		self:ScheduleEvent("VanasKoSFuRemovePlayer_" .. name, self.RemovePlayer, 10, self, name);
		self:UpdateMyText();
	end
end

function VanasKoSFu:RemovePlayer(name)
	for k,v in pairs(nearbyKos) do
		if(v[1] == name) then
			tremove(nearbyKos, k);
		end
	end
	for k,v in pairs(nearbyEnemys) do
		if(v[1] == name) then
			tremove(nearbyEnemys, k);
		end
	end
	for k,v in pairs(nearbyFriendly) do
		if(v[1] == name) then
			tremove(nearbyFriendly, k);
		end
	end
	
	lookupList[name] = nil;
	
	self:UpdateMyText();
end

local text = "";

function VanasKoSFu:UpdateMyText()
	self.text = "|cffff00ff" .. #nearbyKos .. "|r |cffff0000" .. #nearbyEnemys .. "|r |cff00ff00" .. #nearbyFriendly .. "|r";
	self:Update();
end

function VanasKoSFu:ToggleWarnFrame()
	VanasKoSWarnFrame.db.profile.Enabled = not VanasKoSWarnFrame.db.profile.Enabled;
	VanasKoS:ToggleModuleActive("WarnFrame", VanasKoSWarnFrame.db.profile.Enabled);
	VanasKoSWarnFrame:Update();
end

function VanasKoSFu:ToggleMainMenu()
	VanasKoS:ToggleMenu();
end

function VanasKoSFu:OnClick()
	self:ToggleMainMenu();
end

function VanasKoSFu:OnTextUpdate()
	self:SetText(self.text);
end

local dewdrop = AceLibrary("Dewdrop-2.0");

function VanasKoSFu:OnClickAttacker(var)
	VANASKOS.showList = "PLAYERKOS";
	VANASKOS.LastNameEntered = var;
	StaticPopup_Show("VANASKOS_ADD_REASON_ENTRY");
	VanasKoSGUI:Update();
end

function VanasKoSFu:OnTooltipUpdate()
	local cat = tablet:AddCategory(
					'text', L["Last Attackers"],
					'columns', 2);
					
	local list = VanasKoSPvPDataGatherer:GetDamageFromArray();
	for k,v in pairs(list) do
		cat:AddLine('text', v[1],
					'text2', format(L["%s ago"], SecondsToTime(time() - v[2])),
					'textR', 1.0,
					'textG', 0.0,
					'textB', 0.0,
					'text2R', 1.0,
					'text2G', 1.0,
					'text2B', 1.0,
					'func', "OnClickAttacker",
					'arg1', self,
					'arg2', v[1]);
	end
	
	
	if(showWarnFrameInfoText) then
		cat = tablet:AddCategory(
			'text', L["Nearby People"],
			'columns', 1);

		for k,v in pairs(nearbyKos) do
			cat:AddLine('text', v[1],
						'textR', 1.0,
						'textG', 0.0,
						'textB', 1.0)
		end
		for k,v in pairs(nearbyEnemys) do
			cat:AddLine('text', v[1],
						'textR', 1.0,
						'textG', 0.0,
						'textB', 0.0)
		end
		for k,v in pairs(nearbyFriendly) do
			cat:AddLine('text', v[1],
						'textR', 0.0,
						'textG', 1.0,
						'textB', 0.0)
		end
	end
	tablet:SetHint(L["Click to toggle the Main Window"]);
end
